==> cactoos_0.48.orig.tar.gz: cactoos-0.48/src/main/java/org/cactoos/BiProc.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2020 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.cactoos;

import org.cactoos.proc.IoCheckedBiProc;
import org.cactoos.proc.UncheckedBiProc;

/**
 * Proc that accepts two arguments.
 *
 * <p>If you don't want to have any checked exceptions being thrown
 * out of your {@link BiProc}, you can use
 * {@link UncheckedBiProc} decorator. Also
 * you may try {@link IoCheckedBiProc}.</p>
 *
 * <p>There is no thread-safety guarantee.
 *
 * @param <X> Type of input
 * @param <Y> Type of input
 * @since 0.20
 */
public interface BiProc<X, Y> {

    /**
     * Execute it.
     * @param first The first argument
     * @param second The second argument
     * @throws Exception If fails
     */
    void exec(X first, Y second) throws Exception;
}

==> cactoos_0.49.orig.tar.gz: cactoos-0.49/src/main/java/org/cactoos/BiProc.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2020 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.cactoos;

import org.cactoos.proc.IoCheckedBiProc;
import org.cactoos.proc.UncheckedBiProc;

/**
 * Proc that accepts two arguments.
 *
 * <p>If you don't want to have any checked exceptions being thrown
 * out of your {@link BiProc}, you can use
 * {@link UncheckedBiProc} decorator. Also
 * you may try {@link IoCheckedBiProc}.</p>
 *
 * <p>There is no thread-safety guarantee.
 *
 * @param <X> Type of input
 * @param <Y> Type of input
 * @since 0.20
 * @todo #1445:30min Introduce BiProcOf on the model of ProcOf, FuncOf, etc
 *  with constructors taking Func, BiFunc, Proc and BiProc as primary.
 *  Add tests similar to those of ProcOfTest, FuncOfTest, etc to fully cover
 *  the implementation. Use it where needed, for example in AndWithIndexTest.
 */
public interface BiProc<X, Y> {

    /**
     * Execute it.
     * @param first The first argument
     * @param second The second argument
     * @throws Exception If fails
     */
    void exec(X first, Y second) throws Exception;
}
